Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1340)

Unified Diff: Source/core/html/track/TextTrack.cpp

Issue 55653003: Rename TextTrackRegion/TextTrackRegionList to VTTRegion/VTTRegionList (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: update test expectations Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/track/TextTrack.h ('k') | Source/core/html/track/TextTrack.idl » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/track/TextTrack.cpp
diff --git a/Source/core/html/track/TextTrack.cpp b/Source/core/html/track/TextTrack.cpp
index 12626dea6144e2789a3b534a6fb01750b5a2d700..0d26419b0b2dd4db71130083e4542e7cae254e15 100644
--- a/Source/core/html/track/TextTrack.cpp
+++ b/Source/core/html/track/TextTrack.cpp
@@ -39,8 +39,8 @@
#include "core/html/HTMLMediaElement.h"
#include "core/html/track/TextTrackCueList.h"
#include "core/html/track/TextTrackList.h"
-#include "core/html/track/TextTrackRegion.h"
-#include "core/html/track/TextTrackRegionList.h"
+#include "core/html/track/VTTRegion.h"
+#include "core/html/track/VTTRegionList.h"
namespace WebCore {
@@ -279,34 +279,34 @@ void TextTrack::removeCue(TextTrackCue* cue, ExceptionState& es)
m_client->textTrackRemoveCue(this, cue);
}
-TextTrackRegionList* TextTrack::ensureTextTrackRegionList()
+VTTRegionList* TextTrack::ensureVTTRegionList()
{
if (!m_regions)
- m_regions = TextTrackRegionList::create();
+ m_regions = VTTRegionList::create();
return m_regions.get();
}
-TextTrackRegionList* TextTrack::regions()
+VTTRegionList* TextTrack::regions()
{
// If the text track mode of the text track that the TextTrack object
// represents is not the text track disabled mode, then the regions
// attribute must return a live TextTrackRegionList object that represents
// the text track list of regions of the text track. Otherwise, it must
// return null. When an object is returned, the same object must be returned
// each time.
if (RuntimeEnabledFeatures::webVTTRegionsEnabled() && m_mode != disabledKeyword())
- return ensureTextTrackRegionList();
+ return ensureVTTRegionList();
return 0;
}
-void TextTrack::addRegion(PassRefPtr<TextTrackRegion> prpRegion)
+void TextTrack::addRegion(PassRefPtr<VTTRegion> prpRegion)
{
if (!prpRegion)
return;
- RefPtr<TextTrackRegion> region = prpRegion;
- TextTrackRegionList* regionList = ensureTextTrackRegionList();
+ RefPtr<VTTRegion> region = prpRegion;
+ VTTRegionList* regionList = ensureVTTRegionList();
// 1. If the given region is in a text track list of regions, then remove
// region from that text track list of regions.
@@ -318,7 +318,7 @@ void TextTrack::addRegion(PassRefPtr<TextTrackRegion> prpRegion)
// a region with the same identifier as region replace the values of that
// region's width, height, anchor point, viewport anchor point and scroll
// attributes with those of region.
- TextTrackRegion* existingRegion = regionList->getRegionById(region->id());
+ VTTRegion* existingRegion = regionList->getRegionById(region->id());
if (existingRegion) {
existingRegion->updateParametersFromRegion(region.get());
return;
@@ -330,7 +330,7 @@ void TextTrack::addRegion(PassRefPtr<TextTrackRegion> prpRegion)
regionList->add(region);
}
-void TextTrack::removeRegion(TextTrackRegion* region, ExceptionState &es)
+void TextTrack::removeRegion(VTTRegion* region, ExceptionState &es)
{
if (!region)
return;
@@ -279,34 +279,34 @@ void TextTrack::removeCue(TextTrackCue* cue, ExceptionState& es)
// If the text track mode of the text track that the TextTrack object
// represents is not the text track disabled mode, then the regions
- // attribute must return a live TextTrackRegionList object that represents
+ // attribute must return a live VTTRegionList object that represents
// the text track list of regions of the text track. Otherwise, it must
// return null. When an object is returned, the same object must be returned
« no previous file with comments | « Source/core/html/track/TextTrack.h ('k') | Source/core/html/track/TextTrack.idl » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698